==> haskell-resource-pool-0.2.3.2-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-AxpUqZgHU341wPjgPw9ojm
key: resource-pool-0.2.3.2-AxpUqZgHU341wPjgPw9ojm
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Pool
abi: be5be4e86ad49691f32784ec226ad5f3
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-AxpUqZgHU341wPjgPw9ojm
depends:
    base-4.10.1.0 hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR
    monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J transformers-0.5.2.0
    transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2
    stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw time-1.8.0.2
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             hashable-1.2.6.1-6LeHpYZ4iRgEy9P36eCQfR=087c0712ec00d90dbe506989d07212a2
             monad-control-1.0.2.2-EdIoEINWcWuDiJeYd7J09J=e28d37063c38c75b3bf039284c73d58f
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             transformers-base-0.4.4-5PiUpfNfiYhLklP2PyVZJ2=e96596ff8dc8b61f0eaf7d04e05900dc
             stm-2.4.4.1-E6EjE1bszQZJ9orPdUNxjw=05affb1c34b776a775422ef4ed6b6def
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=aa687f07efbeaeb82a30478c8f07e96e
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-EVyRd1M4SMoL9NmERbm3xP
key: resource-pool-0.2.3.2-EVyRd1M4SMoL9NmERbm3xP
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
indefinite: False
exposed-modules:
    Data.Pool
abi: 9b54ab690611e6ac9ba5d39d05ff8efd
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/resource-pool-0.2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-EVyRd1M4SMoL9NmERbm3xP
depends:
    base-4.10.1.0 hashable-1.2.6.1-J6sGOABANQPC82cP9LKvWy
    monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00 transformers-0.5.2.0
    transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl
    stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x time-1.8.0.2
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             hashable-1.2.6.1-J6sGOABANQPC82cP9LKvWy=925e4ef40a93a8ff2534d316e4a6e622
             monad-control-1.0.2.3-CW8aHbBnYkIJ7WUS7rCN00=cb463f07760413dcfa98bc749bfae003
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             transformers-base-0.4.4-E8cVJ8zOMCQDdcbsfJzxdl=ea95310fa3f7f52b12b6f48401dbc7cd
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad99cb175fde1a67819ef6519a4015eb
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=a99b30cfe85615e5f75a9a70e1864f51
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
